package com.ym.mec.im.fallback;

import com.ym.mec.common.entity.*;
import com.ym.mec.im.ImFeignService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;

import javax.xml.ws.Action;
import java.util.List;

@Component
public class ImFeignServiceFallback implements ImFeignService {
    @Override
    public ImResult register(ImUserModel userModel) {
    	
    	System.out.println("*******************");
        return null;
    }

    @Override
    public void update(ImUserModel userModel) {

    }

    @Override
    public Object groupCreate(ImGroupModel groupModel) {
        return null;
    }

    @Override
    public void groupBatchCreate(List<ImGroupModel> groupModels) {

    }

    @Override
    public Object groupJoin(ImGroupModel groupModel) {
        return null;
    }

    @Override
    public Object groupQuit(ImGroupModel groupModel) {
        return null;
    }

    @Override
    public Object groupDismiss(ImGroupModel groupModel) {
        return null;
    }

    @Override
    public Object groupBatchDismiss(List<ImGroupModel> groupModels) {
        return null;
    }

    @Override
    public Object groupBatchQuit(List<ImGroupModel> groupModels) {
        return null;
    }

    @Override
    public Object privateSend(ImPrivateMessage privateMessage) {
        return null;
    }

    @Override
    public Object groupSend(ImGroupMessage imGroupMessage) {
        return null;
    }
/*
    @Override
    public Object privateSendCustom(ImGroupMessage groupMessage) {
        return null;
    }*/
}
